@@ -51,7 +51,7 @@ segregationFun<-function(X, fun="isar", r=NULL, ntype="geometric", funpars=NULL,
 		else
 			parvec <- switch(ntype, "knn"=1:20, 0)
 	}
-	else parvec <- sort(r) # r given. make sure in order.
+	else parvec <- sort(r) # r given. make sure in ascending order.
 	
 	# TODO: for the c++-module coherence with 'spatgraphs', skip mass geometric
 	if(ntypei>1) ntypei <- ntypei+1  
@@ -72,45 +72,44 @@ segregationFun<-function(X, fun="isar", r=NULL, ntype="geometric", funpars=NULL,
 		if(diff(dim(weightMatrix))!=0)	stop("Error segregationFun: weightMatrix not square matrix.")
 		if(!isTRUE(all.equal(colnames(weightMatrix),rownames(weightMatrix))) |
 				!isTRUE(all.equal(colnames(weightMatrix),levels(as.factor(X$marks))))){
-			stop("Error segregationFun: weightMatrix row/column names and order should match to those of X's mark levels.")
+			stop("Error segregationFun: weightMatrix row and column names and order should match X's mark levels.")
 		}
 	}
 	else weightMatrix<-diag(0, ncol=length(levels(as.factor(X$marks))))-1 # no type-to-type weights given
 	
-	# TODO: modify the pp, see below in the function	
+	# modify the pp: convert factor labels to integers, add window area, add border distances. 	
 	X<-sg.modify.pp(X)
 	
-	# if a fixed minus  (border) correction is to be used, compute the ones to exclude
+	# if a minus sampling border correction is to be used, compute the ones to exclude
+	# TRUE + geometric graph => adaptive
+	# positive + any graph => fixed
 	if(is.logical(minusRange)){
 		if(minusRange){
-			included<-rep(-1, X$n)
 			if(ntypei!=0) stop("Error segregationFun: adaptive minus-sampling only for geometric neighbourhood.")
+			included<-rep(-1, X$n)
 			note<-c(note, "adaptive minus-sampling border correction")
 		}
 	}
 	else if(minusRange>0)
 	{
-		included<-minusID.gf(X, minusRange)
+		included<- X$bdist > minusRange
 		note<-c(note,paste("Minus correction, fixed radius=", minusRange, ";", sep=""))
 	}
+	# if we accept that all points are good for computation, included vector is all 1's
+	if(is.null(included) | length(included)!=X$n) included<-rep(1,X$n)
+	
 	# if translation corrected: Only for mingling and Simpson
 	if(translate){
 		note<-c(note,paste("translation correction", sep=""))
-		if(funi!=1 & funi!=3) stop("Translation correction available only for Mingling and Simpson functions/indices.")
+		if(funi!=1 & funi!=3) stop("Translation correction available only for Mingling and Simpson functions and indices.")
 	}
 	
-	# if we accept that all points are good for computation, included vector is all 1's
-	if(is.null(included) | length(included)!=X$n) included<-rep(1,X$n)
-	
 	# check if the prepGraph is given when used as the target neighbourhood configuration
 	if(prepGraphIsTarget && is.null(prepGraph)) stop("Error segregationFun: prepGraph not given but needed for calculation.")
 		
 	# this is for the c-side check to know if we are giving a prepGraph
 	prepGraph$'isnull'<- as.integer(is.null(prepGraph))
 	
-	## add the distance to border
-	X$bdist<-bdist.points(X)
-	
 	# set parameters according to prepGraph
 	if(prepGraphIsTarget)
 	{
@@ -118,10 +117,6 @@ segregationFun<-function(X, fun="isar", r=NULL, ntype="geometric", funpars=NULL,
 		ntype<-prepGraph$type
 	}
 	
-	
-	# include area
-	X$area<-as.numeric(area.owin(X$window))
-	
 	# the main call 
 	res<-.External("fun_c", as.integer(dbg), X, as.numeric(funpars), 
 					as.integer(ntypei), as.numeric(parvec), 
@@ -151,14 +146,14 @@ segregationFun<-function(X, fun="isar", r=NULL, ntype="geometric", funpars=NULL,
 
 #####################
 
-minusID.gf<- function (pp0, minusRange)
-{
-	id <- bdist.points(pp0) > minusRange
-#				(pp0$x < (pp0$window$x[2] - minusRange)) & (pp0$x > (pp0$window$x[1] +
-#					minusRange)) & (pp0$y < (pp0$window$y[2] - minusRange)) & (pp0$y >
-#				(pp0$window$y[1] + minusRange))
-	id
-}
+#minusID.gf<- function (pp0, minusRange)
+#{
+#	id <- bdist.points(pp0) > minusRange
+##				(pp0$x < (pp0$window$x[2] - minusRange)) & (pp0$x > (pp0$window$x[1] +
+##					minusRange)) & (pp0$y < (pp0$window$y[2] - minusRange)) & (pp0$y >
+##				(pp0$window$y[1] + minusRange))
+#	id
+#}
 
 #####################
 sg.modify.pp<-function(pp)
@@ -194,6 +189,12 @@ sg.modify.pp<-function(pp)
 	pp$x<-as.numeric(pp$x)
 	pp$y<-as.numeric(pp$y)
 	pp$z<-as.numeric(pp$z)	
+	
+	## add the distance to border
+	pp$bdist<-bdist.points(pp)
+	# include area
+	pp$area<-as.numeric(area.owin(pp$window))
+	
 	pp
 }
 
